# Docker Cheatsheet (for Novaconium)

## Compose update project

```docker run --rm --interactive --tty --volume $PWD:/app composer:latest update```

## Sample Docker Compose File

```
services:

  corxn: 
    image: ${CORXN_IMAGE}
    restart: always
    volumes:
      - "./novaconium:/data"
      - "./config/php.ini:/usr/local/etc/php/php.ini"
    networks:
      - my_internal
      - proxy
    ports:
      - 8000:80

  mariadb:
    image: ${MARIADB_IMAGE}
    restart: always
    command: --transaction-isolation=READ-COMMITTED --binlog-format=ROW --innodb-file-per-table=1 --skip-innodb-read-only-compressed
    environment:
      - MARIADB_DATABASE=${DB}
      - MARIADB_PASSWORD=${DB_PASSWORD}
      - MARIADB_ROOT_PASSWORD=${DB_ROOT_PASSWORD}
      - MARIADB_USER=${DB_sUSER}
    volumes:
      - ${VOL_PATH}/db:/var/lib/mysql
    networks:
      - my_internal

networks:
  proxy:
    external: true
  my_internal:
    driver: bridge

```

### ENV File

The .env file should look something like this:

```
CORXN_IMAGE=4lights/corxn:latest
TZ=America/Vancouver
VOL_CONFIG_PATH=/data/myProject/config
VOL_PATH=/data/myProject/data

# MariaDB
MARIADB_IMAGE=mariadb:latest
DB=mydbname
DB_ROOT_PASSWORD=ChangeThisPassword0123456789ABCD
DB_PASSWORD=AlsoChangeThisPassword0123456789
DB_USER=dbuser
```

## Start Docker

```docker compose up -d```
